@@ -1,19 +1,36 @@
+import typing as t
+
+from vbcore import uuid
+from vbcore.datastruct import ObjectDict
 from werkzeug.middleware.proxy_fix import ProxyFix
 from werkzeug.urls import url_decode
 
-from .utils import uuid
-from .utils.datastruct import ObjectDict
+if t.TYPE_CHECKING:
+    # pylint: disable=unused-import
+    from _typeshed.wsgi import StartResponse, WSGIApplication, WSGIEnvironment
+
+    from flaskel import Flaskel
 
 
 class BaseMiddleware:
-    # noinspection PyUnresolvedReferences
-    def get_config(self):
+    def __init__(self, app: "WSGIApplication"):
+        self.app = app
+        self._flask_app: t.Optional["Flaskel"] = None
+
+    @property
+    def flask_app(self) -> t.Optional["Flaskel"]:
+        return self._flask_app
+
+    @flask_app.setter
+    def flask_app(self, app: "Flaskel"):
+        self._flask_app = app
+
+    def get_config(self) -> ObjectDict:
         try:
-            # flask_app is added by flaskel factory as a workaround
             if isinstance(self.flask_app.config, ObjectDict):
                 return self.flask_app.config
-            return ObjectDict.normalize(self.flask_app.config)  # pragma: no cover
-        except AttributeError:  # pragma: no cover
+            return ObjectDict.normalize(self.flask_app.config)
+        except AttributeError:
             return ObjectDict()
 
 
@@ -23,23 +40,10 @@ class ForceHttps(BaseMiddleware):
     use ReverseProxied instead
     """
 
-    def __init__(self, app):
-        """
-
-        :param app:
-        """
-        self.app = app
-
-    def __call__(self, environ, start_response):
-        """
-
-        :param environ:
-        :param start_response:
-        :return:
-        """
-        conf = self.get_config()
-        url_scheme = conf.PREFERRED_URL_SCHEME or 'https'
-        environ['wsgi.url_scheme'] = url_scheme
+    def __call__(
+        self, environ: "WSGIEnvironment", start_response: "StartResponse"
+    ) -> t.Iterable[bytes]:
+        environ["wsgi.url_scheme"] = "https"
         return self.app(environ, start_response)
 
 
@@ -72,17 +76,17 @@ class ReverseProxied(ProxyFix, BaseMiddleware):
     environ as werkzeug.proxy_fix.orig, a dict.
     """
 
-    def __init__(self, app, x_for=1, x_proto=1, x_host=1, x_port=0, x_prefix=1):
-        """
-
-        :param app:
-        :param x_for:
-        :param x_proto:
-        :param x_host:
-        :param x_port:
-        :param x_prefix:
-        """
-        super().__init__(app, x_for, x_proto, x_host, x_port, x_prefix)
+    def __init__(
+        self,
+        app: "WSGIApplication",
+        x_for: int = 1,
+        x_proto: int = 1,
+        x_host: int = 1,
+        x_port: int = 0,
+        x_prefix: int = 1,
+    ):
+        ProxyFix.__init__(self, app, x_for, x_proto, x_host, x_port, x_prefix)
+        BaseMiddleware.__init__(self, app)
 
 
 class HTTPMethodOverride(BaseMiddleware):
@@ -94,30 +98,19 @@ class HTTPMethodOverride(BaseMiddleware):
     could result unexpected behavior due to caching.
     """
 
-    def __init__(self, app):
-        """
-
-        :param app:
-        """
-        self.app = app
-
-    def __call__(self, environ, start_response):
-        """
-
-        :param environ:
-        :param start_response:
-        :return:
-        """
+    def __call__(
+        self, environ: "WSGIEnvironment", start_response: "StartResponse"
+    ) -> t.Iterable[bytes]:
         conf = self.get_config()
-        methods = conf.OVERRIDE_METHODS or ('POST',)
-        method = environ.get('HTTP_X_HTTP_METHOD_OVERRIDE', None)
+        methods = conf.OVERRIDE_METHODS or ("POST",)
+        method = environ.get("HTTP_X_HTTP_METHOD_OVERRIDE")
 
-        if '_method_override' in environ.get('QUERY_STRING', ''):
-            args = url_decode(environ['QUERY_STRING'])
-            method = args.get('_method_override')
+        if "_method_override" in environ.get("QUERY_STRING", ""):
+            args = url_decode(environ["QUERY_STRING"])
+            method = args.get("_method_override")
 
-        if method and environ['REQUEST_METHOD'] in methods:
-            environ['REQUEST_METHOD'] = method.upper()
+        if method and environ["REQUEST_METHOD"] in methods:
+            environ["REQUEST_METHOD"] = method.upper()
 
         return self.app(environ, start_response)
 
@@ -128,19 +121,21 @@ class RequestID(BaseMiddleware):
 
     Flask middleware to ensure all requests have a Request ID header present.
     Request IDs can be used when logging errors and allows users to trace requests through multiple
-    layers such as load balancers and reverse proxies. The request ID header value may consist of multiple
-    IDs encoded according to RFC 2616 [1].
+    layers such as load balancers and reverse proxies.
+    The request ID header value may consist of multiple IDs encoded according to RFC 2616 [1].
 
-    This middleware ensures there is always at least one, unique, value, whilst respecting any pre-existing
-    values set by an upstream component or the client. If there isn't a pre-existing value, a single, unique,
-    ID is generated.
-    If there is a pre-existing value, it is split into multiple values as per RFC 2616 and each value checked
-    for uniqueness. If no values are unique an additional, unique, value is added.
+    This middleware ensures there is always at least one, unique, value,
+    whilst respecting any pre-existing values set by an upstream component or the client.
+    If there isn't a pre-existing value, a single, unique, ID is generated.
+    If there is a pre-existing value, it is split into multiple values as per RFC 2616
+    and each value checked for uniqueness.
+    If no values are unique an additional, unique, value is added.
 
     A value is considered unique if it:
     1. is a valid UUID (version 4)
-    2. or, the value is known to be from a component that assigns unique IDs, identified by a common prefix
-       set in the 'REQUEST_ID_PREFIX' Flask config value or `request_id_prefix` class member value.
+    2. or, the value is known to be from a component that assigns unique IDs,
+       identified by a common prefix set in the 'REQUEST_ID_PREFIX' Flask config value
+       or `request_id_prefix` class member value.
 
     To use the Request ID in the current application: `request.environ.get("HTTP_X_REQUEST_ID")`
     For use elsewhere, the Request ID header is included in the response back to the client.
@@ -148,29 +143,18 @@ class RequestID(BaseMiddleware):
     """
 
     # the http header name, overridden via flask app config
-    header_name = 'X-Request-ID'
+    header_name = "X-Request-ID"
 
     # the request id value prefix used to trust uniqueness
     request_id_prefix = None
 
-    def __init__(self, app):
-        """
-
-        :param app: Flask application
-        """
-        self.app = app
-
-    def __call__(self, environ, start_response):
-        """
-
-        :param environ:
-        :param start_response:
-        :return:
-        """
+    def __call__(
+        self, environ: "WSGIEnvironment", start_response: "StartResponse"
+    ) -> t.Iterable[bytes]:
         conf = self.get_config()
         header_name = conf.REQUEST_ID_HEADER or self.header_name
         flask_header_name = f"HTTP_{header_name.upper().replace('-', '_')}"
-        request_id_header = self._compute_request_id_header(environ.get(flask_header_name))
+        request_id_header = self.prepare(environ.get(flask_header_name))
         environ[flask_header_name] = request_id_header
 
         def new_start_response(status, headers, exc_info=None):
@@ -179,7 +163,7 @@ class RequestID(BaseMiddleware):
 
         return self.app(environ, new_start_response)
 
-    def _compute_request_id_header(self, header_value):
+    def prepare(self, header_value: t.Optional[str] = None) -> str:
         """
         Ensures request ID header has at least one, unique, value
 
@@ -189,29 +173,23 @@ class RequestID(BaseMiddleware):
         if header_value is None:
             return uuid.get_uuid()
 
-        for request_id in header_value.split(','):
-            if self._is_unique(request_id):
+        for request_id in header_value.split(","):
+            if self.has_valid_uniqueness(request_id):
                 return header_value
 
         # Append an unique header value
         return f"{header_value},{uuid.get_uuid()}"
 
-    def _is_unique(self, request_id):
+    def has_valid_uniqueness(self, request_id: str) -> bool:
         """
-        Checks whether a Request ID is unique
+        Checks whether a Request ID has a trusted prefix or is a valid uuid
 
         :param request_id: A request ID
         :return: Whether the Request ID is unique or not
         """
         conf = self.get_config()
-        request_id_prefix = conf.REQUEST_ID_PREFIX or self.request_id_prefix
-        if request_id_prefix is not None and \
-                request_id.startswith(request_id_prefix):
+        prefix = conf.REQUEST_ID_PREFIX or self.request_id_prefix
+        if prefix and request_id.startswith(prefix):
             return True  # pragma: no cover
 
-        try:
-            uuid.check_uuid(request_id, exc=True)
-        except ValueError:
-            return False
-        else:
-            return True
+        return uuid.check_uuid(request_id, exc=False)
