@@ -1,4 +1,3 @@
-import flask
 from flask.testing import FlaskClient
 
 from flaskel.builder import AppBuilder
@@ -7,16 +6,14 @@ from flaskel.builder import AppBuilder
 class JSONRPCMixin:
     @staticmethod
     def prepare(method=None, call_id=None, params=None, version="2.0"):
-        payload = {
-            "jsonrpc": version,
-            "method":  method,
-            "params":  params
-        }
+        payload = {"jsonrpc": version, "method": method, "params": params}
         if call_id:
-            payload['id'] = call_id
+            payload["id"] = call_id
         return payload
 
-    def jsonrpc(self, url, method=None, call_id=None, params=None, version="2.0", **kwargs):
+    def jsonrpc(
+        self, url, method=None, call_id=None, params=None, version="2.0", **kwargs
+    ):
         """
 
         :param url:
@@ -27,7 +24,7 @@ class JSONRPCMixin:
         :param kwargs:
         :return:
         """
-        kwargs.setdefault('json', self.prepare(method, call_id, params, version))
+        kwargs.setdefault("json", self.prepare(method, call_id, params, version))
         return self.post(url, **kwargs)
 
     def jsonrpc_batch(self, url, requests, version="2.0", **kwargs):
@@ -37,7 +34,7 @@ class JSONRPCMixin:
 
 class TestClient(FlaskClient, JSONRPCMixin):
     def fetch(self, url, *args, **kwargs):  # pragma: no cover
-        return self.open(url, method='FETCH', *args, **kwargs)
+        return self.open(url, method="FETCH", *args, **kwargs)
 
     @classmethod
     def get_app(cls, conf, **kwargs):
@@ -47,11 +44,9 @@ class TestClient(FlaskClient, JSONRPCMixin):
         :param kwargs:
         :return:
         """
-        app = AppBuilder(**kwargs).get_or_create(conf)
+        app = AppBuilder(**kwargs).create(conf)
         app.test_client_class = cls
         app.TESTING = True
 
-        if not flask.has_app_context():
-            app.app_context().push()
-
+        app.app_context().push()
         return app
